
;
; MCU -------------------------- ST6262C
; Descrizione ------------------ Set-Up del micro e STOP mode con risveglio solo da Reset
;											In STOP si ha PB2 a 1 e PB3 a 0
; Autore ----------------------- E.Marinoni
; Data Inizio ------------------ 09-06-01
; Compilatore ------------------ Raisonance Version 6.1.4 
; Data Ultimo Aggiornamento ---- 11-06-01


	.title  "STOP"
	.vers   "ST6262"       
	.w_on

;****************************************************************************
;*                       VARIABILI DEL MICRO                                *
;****************************************************************************

a       .def    0ffh    ;ACCUMULATOR (REGISTRO ACCUMULATORE)
x       .def    080h    ;X REGISTER  (REGISTRO X)
y       .def    081h    ;Y REGISTER  (REGISTRO Y)
v       .def    082h    ;V REGISTER  (REGISTRO V)
w       .def    083h    ;W REGISTER  (REGISTRO W)
port_a  .def    0c0h    ;PORT A DATA REGISTER
port_b  .def    0c1h    ;PORT B DATA REGISTER
port_c  .def    0c2h    ;PORT C DATA REGISTER
pdir_a  .def    0c4h    ;PORT A DIRECTION REGISTER  
pdir_b  .def    0c5h    ;PORT B DIRECTION REGISTER
pdir_c  .def    0c6h    ;PORT C DIRECTION REGISTER
popt_a  .def    0cch    ;PORT A OPTION REGISTER
popt_b  .def    0cdh    ;PORT B OPTION REGISTER
popt_c  .def    0ceh    ;PORT C OPTION REGISTER
ior     .def    0c8h    ;INTERRUPT OPTION REGISTER.
addr    .def    0d0h    ;A/D DATA REGISTER (REGISTRO DATI DEL CONVERTITORE)
adcr    .def    0d1h    ;A/D CONTROL REGISTER (REGISTRO DI CONTROLLO)
psc     .def    0d2h    ;TIMER PRESCALER REGISTER (REGISTRO DEL PRESCALER)
tcr     .def    0d3h    ;TIMER DATA REGISTER (REGISTRO DATI)
tscr    .def    0d4h    ;TIMER TSCR REGISTER ( REGISTRO PER IL CONTROLLO
								;DELLO STATO DEL TIMER)
artmcr  .def	 0d5h		;ART Mode Control Register
artscr1 .def 	 0d6h		;ART Status Control Register_1
artscr2 .def 	 0d6h		;ART Status Control Register_2	
osgr    .def	 0dch		;Oscillator Control Register
dreep	  .def	 0e8h		;Data RAM-EEPROM Register
eepcr   .def	 0eah		;EEPROM Control Register
wdog    .def    0d8h    ;WATCHDOG REGISTER
drw     .def    0c9h    ;DATA ROM WINDOW REGISTER


;****************************************************************************
;*                         VARIABILI DEL PROGRAMMA                          *
;****************************************************************************



;****************************************************************************
;*                         SETTAGGIO INIZIALE                               *
;****************************************************************************
	.org  0880h   
inizio                  
	ldi   wdog,0ffh       		; Wdog ON

;      SETTAGGIO DELLA PORTA "A"
;      ------------------------
	ldi   pdir_a,00000000b     ; PA4, PA5 InPut With Pull-Up No Interrupt
	ldi   popt_a,00000000b     ; le altre in OutPut a 0
	ldi   port_a,00000000b        

;      SETTAGGIO DELLA PORTA "C"
;      -------------------------
	ldi   pdir_c,00000000b		; PC2, PC3 InPut With Pull-Up No Interrupt
	ldi   popt_c,00000000b		; le altre in OutPut a 0
	ldi   port_c,00000000b

;      SETTAGGIO DELLA PORTA "B" 
;      -------------------------
	ldi   pdir_b,10001100b     ; PB7,2,3 OutPut Open Drain
	ldi   popt_b,01000000b     ; PB6 InPut Pull-Up and Interrupt
	ldi   port_b,00000001b        
	nop
	nop
	ldi   pdir_b,10001100b     ; PB7,2,3 OutPut Push-Pull
	ldi   popt_b,11001100b     ; PB6 InPut Pull-Up and Interrupt
	ldi   port_b,00000001b     	

	ldi   ior,0           		;DISABLE ALL INTERRUPT
	reti                    	;RIPRISTINA I FLAG PRINCIPALI

;***************************************************************************
;*                         PROGRAMMA PRINCIPALE                            *
;***************************************************************************
main 
;	ldi   wdog,0ffh
	ldi   port_b,00000100b     ;PB2=1, PB3=0   
;	ldi	ior,01110000b
	nop
	nop
	nop
; Setto gli I/O per il minimo consumo
;      SETTAGGIO DELLA PORTA "A"
;      ------------------------
;	ldi   pdir_a,00000000b		; InPut NO Pull-Up
;	ldi   popt_a,00000000b
;	ldi   port_a,00110000b        
;      SETTAGGIO DELLA PORTA "C"
;      -------------------------
;	ldi   pdir_c,00000000b		; InPut NO Pull-Up
;	ldi   popt_c,00000000b			
;	ldi   port_c,00001100b
;      SETTAGGIO DELLA PORTA "B" 
;      -------------------------
;	ldi   pdir_b,10001100b     ; PB7,2,3 OutPut Push-Pull
;	ldi   popt_b,11001100b     ; PB6 InPut Pull-Up and Interrupt
;	ldi   port_b,00000001b     	

; Disabilito tutte le periferiche e vado in STOP
;	ldi   adcr,0          		;Disable A/D
;	ldi   tscr,0          		;Disable TIMER 
;	ldi	artmcr,0					;Disable ARTimer
	ldi	eepcr,01000000b		;Disable EEPROM
;	ldi   ior,0           		;DISABLE ALL INTERRUPT
;	ldi   osgr,#08h        		;Low Power
;	ldi	dreep,0					;Disable RAM/EEPROM
	nop
	nop
	nop
	stop

	jp	   main
	

;****************************************************************************
;*                       SUBROUTINE DI INTERRUPT                            *
;****************************************************************************
int_4   reti                  ;INTERRUPT v4
int_3   reti                  ;INTERRUPT v3
int_2   reti                  ;INTERRUPT v2
int_1	  reti                  ;INTERRUPT v1
nmi_int reti                  ;INTERRUPT v0

;****************************************************************************
;*                         SUBROUTINE                                       *
;****************************************************************************



;****************************************************************************
;*                     VETTORI DI INTERRUPTS                                *
;****************************************************************************

	.org    0ff0h
	jp      int_4   				;INTERRUPT    vector #4
	jp      int_3   				;INTERRUPT    vector #3
	jp      int_2   				;INTERRUPT    vector #2
	jp      int_1   				;INTERRUPT    vector #1
	.org    0ffch
	jp      nmi_int 				;INTERRUPT NON MASCHERABILE  vector #0
	jp      inizio  				;INTERRUZIONE PER IL SETTAGGIO INIZIALE

	.end                    
